#!/usr/bin/perl
# this script parses a TeX hyphenation file to a format usable by substrings.pl
# first argument is the file to generate
# second argument is the dir to find the original file in

# this program gets the basename of the file to generate, and based on that,
# finds the right tex file using the given hash


use File::Basename;

my %tex = (
  "bg"    => "hyphen/bghyphen.tex",
  "ca"    => "hyphen/cahyph.tex",
  "cs"    => "hyphen/czhyph2e.tex",
  # what can we do about the german one ?
  "dk"	  => "hyphen/dkcommon.tex",
  "en_US" => "hyphen/ushyph1.tex",
  "en_GB" => "hyphen/ukhyphen.tex",
  "fi"	  => "hyphen/fihyph.tex",
  "fr"	  => "hyphen/frhyph.tex",
  # ga is galician for tex and irish in locales
  "nl"    => "hyphen/nehyph2.tex",
);
 
# INPUT: 
# - name of file to generate
# - full path to the tex generic/ dir
my $outputfile = shift @ARGV or die "Please give a file name to generate";
my $filename = (fileparse ($outputfile, '\..+'))[0];
my $texpath = shift @ARGV or 
               die "Please give the path to the tex generic/dir";

# print "DEBUG: looking up $filename\n";
my $inputname = $tex{$filename};
if (!$inputname) 
{ 
  die "File $outputname has no TeX source file listed";
}

$inputfile = $texpath . "/" . $inputname;

# print "DEBUG: making $outputfile from $inputfile\n";

if (! -e $inputfile)
{
  die "File $inputfile not found";
}

open INPUT, $inputfile or die "Can't open $inputfile for reading";
open OUTPUT, ">$outputfile" or die "Can't open $outputfile for writing";;

while (<INPUT>)
{
  # stop lines starting with \ at the start
  if (/^\\/) { next; }
  # pass lines with comments in it
  elsif (/\%/) { print OUTPUT; }
  # stop lines with - (exceptions) or {} (tex code)
  elsif (/[{\-}]/) { next; }
  # pass all else
  else { print OUTPUT; }
}
